"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const src_1 = require("../src");
const path = require("path");
jest.mock('../src/convert');
global.console = {
    ...global.console,
    error: jest.fn(),
};
describe('CLI', () => {
    afterEach(() => {
        jest.resetModules();
        src_1.generateLcovFile.mockClear();
        console.error.mockClear();
    });
    it('should call generate lcov file', async () => {
        jest.mock('meow', () => {
            return jest.fn().mockImplementation(() => {
                return {
                    input: ['fixtures/firestore-coverage.json'],
                    flags: {
                        projectRoot: '.',
                        rulesFile: 'fixtures/firestore.rules',
                        output: 'coverage',
                    },
                };
            });
        });
        await Promise.resolve().then(() => require('../src/cli'));
        expect(src_1.generateLcovFile).toBeCalledTimes(1);
        expect(src_1.generateLcovFile).toBeCalledWith('fixtures/firestore-coverage.json', path.resolve('.'), path.resolve('fixtures/firestore.rules'), 'coverage');
    });
    it('fails without input', async () => {
        jest.mock('meow', () => {
            return jest.fn().mockImplementation(() => {
                return {
                    input: [],
                    flags: {
                        projectRoot: '.',
                        rulesFile: 'fixtures/firestore.rules',
                        output: 'coverage',
                    },
                };
            });
        });
        await Promise.resolve().then(() => require('../src/cli'));
        expect(src_1.generateLcovFile).toBeCalledTimes(0);
        expect(console.error).toBeCalledTimes(1);
        expect(console.error).toBeCalledWith(`Missing required <input>
   Use: firebase-rules-coverage <input>`);
    });
});
//# sourceMappingURL=cli.test.js.map